@@ -20,6 +20,7 @@ from functools import _make_key, RLock
 from collections import namedtuple
 import unittest
 import time
+import textwrap
 
 _CacheInfo = namedtuple("CacheInfo", ["hits", "misses", "maxsize", "currsize"])
 
@@ -406,10 +407,10 @@ def get_hints(ss):
     try:
         ss = textwrap.dedent(ss)
         ss = ss.replace('''"""''', "").strip()
-        hints = ["hints:", ]
+        hints = ["hints:", "hint:"]
         j = np.argmax([ss.lower().find(h) for h in hints])
         h = hints[j]
-        ss = ss[ss.find(h) + len(h) + 1:]
+        ss = ss[ss.lower().find(h) + len(h) + 1:]
         ss = "\n".join([l for l in ss.split("\n") if not l.strip().startswith(":")])
         ss = textwrap.dedent(ss)
         ss = ss.strip()
@@ -459,7 +460,7 @@ class UTestCase(unittest.TestCase):
         self.tearDown()
         if self._with_coverage:
             from pathlib import Path
-            from snipper import snipper
+            from snipper import snipper_main
             self.cov.stop()
             data = self.cov.get_data()
             base, _, _ = self._report._import_base_relative()
@@ -473,7 +474,7 @@ class UTestCase(unittest.TestCase):
                     lines = s.splitlines()
                     garb = 'GARBAGE'
 
-                    lines2 = snipper.censor_code(lines, keep=True)
+                    lines2 = snipper_main.censor_code(lines, keep=True)
                     assert len(lines) == len(lines2)
 
                     for l in data.contexts_by_lineno(file):
@@ -487,7 +488,7 @@ class UTestCase(unittest.TestCase):
                             for j in range(l, -1, -1):
                                 if "def" in lines2[j] or "class" in lines2[j]:
                                     break
-                            from snipper.snipper import gcoms
+                            from snipper.legacy import gcoms
                             fun = lines2[j]
                             comments, _ = gcoms("\n".join(lines2[j:l]))
                             if rel not in cc:
@@ -582,7 +583,8 @@ class UTestCase(unittest.TestCase):
         self.wrap_assert(self.assertEqual, first, msg)
 
     def _cache_file(self):
-        return os.path.dirname(inspect.getfile(self.__class__)) + "/unitgrade/" + self.__class__.__name__ + ".pkl"
+        # The filename-directory stuff is a bit tricky but this seems robust.
+        return os.path.dirname(inspect.getabsfile(type(self))) + "/unitgrade/" + self.__class__.__name__ + ".pkl"
 
     def _save_cache(self):
         # get the class name (i.e. what to save to).
@@ -602,6 +604,7 @@ class UTestCase(unittest.TestCase):
         cfile = self._cache_file()
         if os.path.exists(cfile):
             try:
+                # print("\ncache file", cfile)
                 with open(cfile, 'rb') as f:
                     data = pickle.load(f)
                 self.__class__._cache = data
@@ -633,7 +636,8 @@ class UTestCase(unittest.TestCase):
                                     hint = get_hints(comments)
 
                                     if hint != None:
-                                        hints.append(hint)
+                                        # hint = textwrap.dedent(hint)
+                                        hints.append((hint, file, l) )
                                     gprint(f">      - {l}")
 
                 er = er[0]
@@ -641,10 +645,16 @@ class UTestCase(unittest.TestCase):
                 if doc is not None:
                     hint = get_hints(er._testMethodDoc)
                     if hint is not None:
-                        hints = [hint] + hints
+                        hints = [(hint, None, self.cache_id()[1] )] + hints
                 if len(hints) > 0:
-                    gprint("> Hints:")
-                    gprint(textwrap.indent("\n".join(hints), ">   "))
+                    for hint, file, method in hints:
+                        s = (f"'{method.strip()}'" if method is not None else "")
+                        if method is not None and file is not None:
+                            s += " in "
+                        s += (file.strip() if file is not None else "")
+                        gprint(">")
+                        gprint("> Hints (from " + s  + ")")
+                        gprint(textwrap.indent(hint, ">   "))
 
         super()._feedErrorsToResult(result, errors)
 
